@@ -3,12 +3,10 @@ import string
 import subprocess
 import json
 import logging
-import requests
 
 from cloudbench.cloud import CloudUnavailableError
-
 from cloudbench.cloud.base import BaseVolume, BaseMetadataServerCloud
-from cloudbench.cloud.factory import make_metadata_prop
+
 
 logger = logging.getLogger(__name__)
 
@@ -20,11 +18,14 @@ class GCE(BaseMetadataServerCloud):
     provider = "GCE"
 
     metadata_server = "http://metadata/computeMetadata/v1beta1"
-    fq_instance_type = make_metadata_prop("instance/machine-type")
-    fq_availability_zone = make_metadata_prop("instance/zone")
 
-    def __init__(self):
-        self.session = requests.Session()
+    @property
+    def fq_instance_type(self):
+        return self._get_metadata_path("instance/machine-type")
+
+    @property
+    def fq_availability_zone(self):
+        return self._get_metadata_path("instance/zone")
 
     @property
     def instance_type(self):
